==> popmon-0.3.9.tar.gz: popmon-0.3.9/popmon/decorators/spark.py <==
# Copyright (c) 2020 ING Wholesale Banking Advanced Analytics
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


from popmon.hist.filling import make_histograms
from popmon.pipeline.metrics import df_stability_metrics
from popmon.pipeline.report import df_stability_report

try:
    from pyspark.sql import DataFrame

    # add function to create histogrammar histograms
    DataFrame.pm_make_histograms = make_histograms
    # add function to create stability report
    DataFrame.pm_stability_report = df_stability_report
    # add function to create metrics over time without stability report
    DataFrame.pm_stability_metrics = df_stability_metrics
except (ModuleNotFoundError, AttributeError):
    pass

==> popmon-0.4.0.tar.gz: popmon-0.4.0/popmon/decorators/spark.py <==
# Copyright (c) 2020 ING Wholesale Banking Advanced Analytics
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


from histogrammar.dfinterface.make_histograms import make_histograms

from popmon.pipeline.metrics import df_stability_metrics
from popmon.pipeline.report import df_stability_report

try:
    from pyspark.sql import DataFrame

    # add function to create histogrammar histograms
    DataFrame.pm_make_histograms = make_histograms
    # add function to create stability report
    DataFrame.pm_stability_report = df_stability_report
    # add function to create metrics over time without stability report
    DataFrame.pm_stability_metrics = df_stability_metrics
except (ModuleNotFoundError, AttributeError):
    pass
